Module config

Module config 

Action Amphorae command

Wraps invoking of the v2/octavia/amphorae/{amphora_id}/config with PUT method

Structs

AmphoraeCommand
Update the amphora agent configuration. This will push the new configuration to the amphora agent and will update the configuration options that are mutable.