pub struct PoolCommand { /* private fields */ }Expand description
Creates a pool for a load balancer.
The pool defines how requests should be balanced across the backend member servers.
This operation provisions a pool by using the configuration that you define in the request object. After the API validates the request and starts the provisioning process, the API returns a response object, which contains a unique ID.
In the response, the pool provisioning status is ACTIVE,
PENDING_CREATE, or ERROR.
If the status is PENDING_CREATE, issue GET /v2/lbaas/pools/{pool_id} to
view the progress of the provisioning operation. When the pool status
changes to ACTIVE, the pool is successfully provisioned and is ready for
further configuration.
At a minimum, you must specify these pool attributes:
Some attributes receive default values if you omit them from the request:
If the API cannot fulfill the request due to insufficient data or data that
is not valid, the service returns the HTTP Bad Request (400) response
code with information about the failure in the response body. Validation
errors require that you correct the error and submit the request again.
Specifying a project_id is deprecated. The pool will inherit the project_id of the parent load balancer.
You can configure all documented features of the pool at creation time by specifying the additional elements or attributes in the request.
To create a pool, the parent load balancer must have an ACTIVE
provisioning status.
SOURCE_IP_PORT algorithm is available from version 2.13.
Implementations
Sourceimpl PoolCommand
impl PoolCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action