pub struct MemberCommand { /* private fields */ }Expand description
This operation provisions a member and adds it to a pool by using the configuration that you define in the request object. After the API validates the request and starts the provisioning process, it returns a response object, which contains a unique ID.
In the response, the member provisioning status is
ACTIVE, PENDING_CREATE, or ERROR.
If the status is PENDING_CREATE, issue GET
/v2/lbaas/pools/{pool_id}/members/{member_id} to view the progress of the
provisioning operation. When the member status changes to ACTIVE, the
member is successfully provisioned and is ready for further configuration.
If the API cannot fulfill the request due to insufficient data or data that
is not valid, the service returns the HTTP Bad Request (400) response
code with information about the failure in the response body. Validation
errors require that you correct the error and submit the request again.
At a minimum, you must specify these member attributes:
Some attributes receive default values if you omit them from the request:
If you omit the subnet_id parameter, the vip_subnet_id for the parent
load balancer will be used for the member subnet UUID.
The member address does not necessarily need to be a member of the
subnet_id subnet. Members can be routable from the subnet specified
either via the default route or by using host_routes defined on the
subnet.
Administrative users can specify a project ID that is different than their own to create members for other projects.
monitor_address and/or monitor_port can be used to have the health
monitor, if one is configured for the pool, connect to an alternate IP
address and port when executing a health check on the member.
To create a member, the load balancer must have an ACTIVE provisioning
status.
Implementations
Sourceimpl MemberCommand
impl MemberCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action