Create Member command
Wraps invoking of the v2/lbaas/pools/{pool_id}/members with POST method
Structs
- Member
Command - This operation provisions a member and adds it to a pool by using the configuration that you define in the request object. After the API validates the request and starts the provisioning process, it returns a response object, which contains a unique ID.